InMemoryCredentialStore class
In-memory credential store (for testing / development).
- Inheritance
-
- Object
- CredentialStore
- InMemoryCredentialStore
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteApiKey(
String providerId) → Future< void> -
Delete the API key for a provider.
override
-
deleteOAuthToken(
String providerId) → Future< void> -
Delete the OAuth token for a provider.
override
-
getApiKey(
String providerId) → Future< String?> -
Get the API key for a provider.
override
-
getOAuthToken(
String providerId) → Future< Map< String, dynamic> ?> -
Get the OAuth token for a provider.
override
-
hasCredentials(
String providerId) → Future< bool> -
Check if a provider has credentials configured.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveApiKey(
String providerId, String apiKey) → Future< void> -
Save an API key for a provider.
override
-
saveOAuthToken(
String providerId, Map< String, dynamic> token) → Future<void> -
Save an OAuth token for a provider.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited