ModelRegistry class
Model registry with search and filtering capabilities.
Constructors
- ModelRegistry(ProviderRegistry _providerRegistry)
Properties
-
all
→ List<
AIModel> -
All available models.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imageModels
→ List<
AIModel> -
Get models that support image input.
no setter
-
providerIds
→ List<
String> -
Get available providers.
no setter
-
reasoningModels
→ List<
AIModel> -
Get models that support reasoning.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
byApi(
ApiType api) → List< AIModel> - Get models by API type.
-
byProvider(
String providerId) → List< AIModel> - Get models by provider.
-
find(
String providerId, String modelId) → AIModel? - Find a specific model by provider and id.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
search(
String query) → List< AIModel> - Search models by name or id.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited